--[[ ---------------------------------------------------------------------------
Name:	SimpleUnitFrames
Author:	Pneumatus
About:	An extension to the default WoW Unit Frames. Rather than a complete 
		unitframe replacement, this addon adds further information and features
		to the existing frames and allows a greater degree of customization to 
		enhance their usability.
----------------------------------------------------------------------------- ]]

local _G, select = _G, select
local UnitClass, UnitPowerMax, UnitPower = 
	  UnitClass, UnitPowerMax, UnitPower

local DogTag = LibStub("LibDogTag-3.0")
local DogTag_Unit = LibStub("LibDogTag-Unit-3.0")

local L = DogTag_Unit.L

local function AlternatePowerMP_func(unit)
	if unit == "player" then
		return UnitPower(unit,0)
	end
end
local function MaxAlternatePowerMP_func(unit)
	if unit == "player" then
		return UnitPowerMax(unit,0)
	end
end

local mpEvents = "AlternatePowerMana;UNIT_POWER#$unit;UNIT_MAXPOWER#$unit"

DogTag:AddTag("Unit", "AlternatePowerMP", {
	code = function(args)
		return AlternatePowerMP_func
	end,
	dynamicCode = true,
	arg = {
		'unit', 'string;undef', 'player'
	},
	ret = "number;nil",
	events = mpEvents,
	doc = L["Return the current mana of unit if unit is you"],
	example = ('[AlternatePowerMP] => "%d"'):format(UnitPowerMax("player",0)*.632),
	category = L["Power"],
})

DogTag:AddTag("Unit", "MaxAlternatePowerMP", {
	code = function(args)
		return MaxAlternatePowerMP_func
	end,
	dynamicCode = true,
	arg = {
		'unit', 'string;undef', 'player'
	},
	ret = "number;nil",
	events = mpEvents,
	doc = L["Return the maximum mana of unit if unit is you"],
	example = ('[MaxAlternatePowerMP] => "%d"'):format(UnitPowerMax("player",0)),
	category = L["Power"],
})

DogTag:AddTag("Unit", "PercentAlternatePowerMP", {
	alias = "[AlternatePowerMP(unit=unit) / MaxAlternatePowerMP(unit=unit) * 100]:Round(1)",
	arg = {
		'unit', 'string;undef', 'player'
	},
	doc = L["Return the percentage mana of unit if unit is you"],
	example = '[PercentAlternatePowerMP] => "63.2"; [PercentAlternatePowerMP:Percent] => "63.2%"',
	category = L["Power"],
})

DogTag:AddTag("Unit", "MissingAlternatePowerMP", {
	alias = "MaxAlternatePowerMP(unit=unit) - AlternatePowerMP(unit=unit)",
	arg = {
		'unit', 'string;undef', 'player'
	},
	doc = L["Return the missing mana of unit if unit is you"],
	example = ('[MissingAlternatePowerMP] => "%d"'):format(UnitPowerMax("player",0)*.368),
	category = L["Power"]
})

DogTag:AddTag("Unit", "FractionalAlternatePowerMP", {
	alias = "Concatenate(AlternatePowerMP(unit=unit), '/', MaxAlternatePowerMP(unit=unit))",
	arg = {
		'unit', 'string;undef', 'player'
	},
	doc = L["Return the current and maximum mana of unit if unit is you"],
	example = ('[FractionalAlternatePowerMP] => "%d/%d"'):format(UnitPowerMax("player",0)*.632, UnitPowerMax("player",0)),
	category = L["Power"]
})

DogTag:AddTag("Unit", "IsMaxAlternatePowerMP", {
	alias = "Boolean(AlternatePowerMP(unit=unit) = MaxAlternatePowerMP(unit=unit))",
	arg = {
		'unit', 'string;undef', 'player'
	},
	doc = L["Return True if at max mana, unit is you"],
	example = ('[IsMaxAlternatePowerMP] => %q; [IsMaxAlternatePowerMP] => ""'):format(L["True"]),
	category = L["Power"]
})
